import type { FormItemRule, GridItemProps, ButtonProps, GridProps, TooltipProps } from "naive-ui";
import type { CSSProperties, VNode } from "vue";
import type { FormActionType } from "./formAction";
import type { VNodeChild } from "vue";
export interface FormProps {
    modelValueName?: string;
    model?: Record<string, any>;
    showLabel?: boolean;
    labelWidth?: number | string | "auto";
    labelAlign?: import("./Rule").LabelAlign;
    labelPlacement?: import("./Rule").LabelPlacement;
    colon?: string;
    schemas?: FormSchema[];
    inline?: boolean;
    layout?: string;
    size?: import("./Rule").FormSize;
    showActionButtonGroup?: boolean;
    showResetButton?: boolean;
    resetButtonOptions?: Partial<ButtonProps>;
    showSubmitButton?: boolean;
    submitButtonOptions?: Partial<ButtonProps>;
    showAdvancedButton?: boolean;
    submitButtonText?: string;
    resetButtonText?: string;
    gridProps?: GridProps;
    baseGridStyle?: CSSProperties;
    collapsedRows?: number;
    showRequireMark?: boolean;
    requireMarkPlacement?: import("./Rule").RequiredMarkPlacement;
    validateMessages?: any;
    loading?: boolean;
    disabled?: boolean;
    rules?: {
        [schemaField: string]: FormItemRule | FormItemRule[];
    };
}
export type Return<Args = undefined, Result = string | VNode> = (arg: Args) => Result;
export interface FormSchema<ComponentType = string, DefaultValue = unknown, ComponentProps = Record<string, any>> {
    modelValueName?: string;
    field: string;
    label?: string | Return<{
        colon?: string;
    }, VNode | VNodeChild>;
    labelWidth?: number | string | "auto";
    labelAlign?: import("./Rule").LabelAlign;
    labelPlacement?: import("./Rule").LabelPlacement;
    helpMessage?: string;
    helpMessageToolTipProps?: TooltipProps;
    helpMessageIcon?: Return<undefined, VNode>;
    helpMessageIconProps?: CSSProperties & Record<string, any>;
    defaultValue?: DefaultValue;
    component: ComponentType;
    componentProps?: ComponentProps | SchemaFunctionalCall<SchemaCallParams, ComponentProps>;
    rule?: FormItemRule | FormItemRule[];
    colProps?: GridItemProps;
    size?: import("./Rule").FormSize;
    ifShow?: boolean | SchemaFunctionalCall<Pick<SchemaCallParams, "values" | "field">, boolean>;
    show?: boolean | SchemaFunctionalCall<Pick<SchemaCallParams, "values" | "field">, boolean>;
    contentRender?: SchemaFunctionalCall<SchemaCallParams, VNode | string>;
    slot?: string;
    feedback?: string;
    first?: boolean;
    validationStatus?: import("./Rule").ValidateStatus;
}
export type SchemaCallParams = {
    model: Readonly<Record<string, any>>;
    readonly field: string;
    readonly values: Readonly<Record<string, any>>;
    readonly action: FormActionType;
    readonly schema: FormSchema;
};
export type SchemaFunctionalCall<Params = SchemaCallParams, Render = VNode, ExtraArg = any> = (params: Params, ...args: ExtraArg[]) => Render;
export type SetFormValue = <T = any>(key: string, value: T) => {
    key: string;
    value: T;
    values: Record<string, any>;
};
export type FormContext = {
    formModel: Record<string, any>;
    values: Readonly<Record<string, any>>;
    schemas: FormSchema[];
    action: FormActionType;
};
